@@ -7,6 +7,8 @@
  * Copyright 2001 Sun Microsytems, Inc.
  */
 
+#undef GTK_DISABLE_DEPRECATED
+
 #include "config.h"
 #include <string.h>
 
@@ -40,6 +42,7 @@ exit_cb (GtkWidget *widget, gpointer user_data)
 int
 main (int argc, char **argv)
 {
+	GnomeProgram *program;
 	GtkWidget *window;
 	GtkWidget *control;
 	gchar     *iid;
@@ -51,7 +54,7 @@ main (int argc, char **argv)
 
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("test-events", VERSION,
+	program = gnome_program_init ("test-events", VERSION,
 			    LIBBONOBOUI_MODULE,
 			    argc, argv, NULL);
 
@@ -74,5 +77,7 @@ main (int argc, char **argv)
 
 	gtk_main ();
 
+	g_object_unref (program);
+
 	return bonobo_debug_shutdown ();
 }
